@@ -90,20 +90,20 @@ class TreeDB(BaseDB):
 
         if not flag:
             if sub_key:
-                flag = TRDB_OPKF_OPENEXIST if '\\' in sub_key else TRDB_OPKF_DOTPATH
+                flag = TRDB_OPKF_OPENEXIST if '\\' in sub_key else TRDB_OPKF_OPENEXIST | TRDB_OPKF_DOTPATH
             else:
-                flag = TRDB_OPKF_OPENEXIST if '\\' in main_key else TRDB_OPKF_DOTPATH
+                flag = TRDB_OPKF_OPENEXIST if '\\' in main_key else TRDB_OPKF_OPENEXIST | TRDB_OPKF_DOTPATH
 
         if sub_key:
-            _host, _port = self._get_host_port(main_key)
-            host, port = host or _host, port or _port
             try:
                 self.exec_tree('Treedb_ReopenMainKey', sub_key, flag, path_flag, main_key, main_key_pwd, file)
             except DBError:
                 try:
+                    _host, _port = self._get_host_port(main_key)
+                    host, port = host or _host, port or _port
                     self.__chl = CBSHandleLoc()
                     self.exec_tree('Treedb_Alloc', host, file, main_key, main_key_pwd, TRDB_OPKF_OPENEXIST, port)
-                    logging.warning('正在重新连接数据库并打开主键[%s]-子键[%s]' % (main_key, sub_key))
+                    logging.debug('正在重新连接数据库并打开主键[%s]-子键[%s]' % (main_key, sub_key))
                     self.exec_tree('Treedb_ReopenSubKey', sub_key, flag)
                 except DBError as e:
                     raise DBError(e.err_code, '打开主键[%s]-子键[%s]时' % (main_key, sub_key))
@@ -119,11 +119,26 @@ class TreeDB(BaseDB):
                         host, port = host or _host, port or _port
                         self.__chl = CBSHandleLoc()
                         self.exec_tree('Treedb_Alloc', host, file, main_key, main_key_pwd, TRDB_OPKF_OPENEXIST, port)
-                        logging.warning('正在重新连接tree数据库并打开主键[%s]' % main_key)
+                        logging.debug('正在重新连接tree数据库并打开主键[%s]' % main_key)
                     except DBError as e:
                         raise DBError(e.err_code, '打开主键[%s]时' % main_key)
         return self
 
+    @classmethod
+    def file_names(cls, host: str = None, port: int = None) -> list:
+        """
+        获取数据库所有数据库名
+        eg: TreeDB.main_keys(host='127.0.0.1', port=8123)
+
+        :param host: 主机
+        :param port: 端口
+        """
+        host, port = cls._check_conn_params(cls, host, port)
+
+        res_list = list()
+        cls.exec_class('bs_tabledb_get_all_dbnames', res_list, host, port)
+        return res_list
+
     @classmethod
     def main_keys(cls, file: str, host: str = None, port: int = None) -> list:
         """
@@ -135,7 +150,7 @@ class TreeDB(BaseDB):
         :param port: 端口
         """
 
-        host, port = cls._check_conn_params(cls, host, port)
+        host, port = cls._check_conn_params(cls, host, port, file)
 
         res_list = list()
         cls.exec_class('Treedb_GetAllMainKeyNames', res_list, host, file, port)
@@ -217,7 +232,7 @@ class TreeDB(BaseDB):
         :param port: 端口
         """
 
-        host, port = cls._check_conn_params(cls, host, port)
+        host, port = cls._check_conn_params(cls, host, port, file_name)
         return cls.exec_class('Treedb_CreateFile', host, file_name, port)
 
     @classmethod
@@ -233,7 +248,7 @@ class TreeDB(BaseDB):
         :param port: 端口
         """
 
-        host, port = cls._check_conn_params(cls, host, port)
+        host, port = cls._check_conn_params(cls, host, port, file)
         return cls.exec_class('Treedb_CreateMainKey', host, file, main_key, main_pwd, port)
 
     def insert_sub_keys(self, sub_keys: Union[str, list], flag: int = TDDB_OPKF_CREATEDYNKEY) -> Union[str, list]:
