@@ -5,7 +5,6 @@
 import json
 import sys
 import typing as t
-from itertools import chain
 
 from pydantic import ValidationError
 
@@ -65,7 +64,7 @@ class Mx(BaseMx):
             data = json.dumps({'status': 'success', 'errmsg': data[0], 'data': data[1] if len(data) == 2 else data[1:]},
                               ensure_ascii=False)
         else:
-            data = json.dumps({'status': 'failed', 'errmsg': data}, ensure_ascii=False)
+            data = json.dumps({'status': 'failed', 'errmsg': data, 'err_type': ''}, ensure_ascii=False)
 
         if callback:
             data = '%s(%s)' % (callback, data)
@@ -81,7 +80,7 @@ class Mx(BaseMx):
         """
         request = self.set_response(request)
         if isinstance(res, Response):
-            res = str(res)
+            res = res()
         else:
             res = self.package_data(res, request.callback)
         return request.session, res
@@ -99,6 +98,7 @@ class Mx(BaseMx):
         :return:
         """
         self.session_handler = Request(session)
+        self.session_handler.url_map = self.url_map
 
         global session_handler
         session_handler = self.session_handler
@@ -131,9 +131,9 @@ class Mx(BaseMx):
         self.session_handler = self.set_response(self.session_handler)
 
         error = json.dumps({'status': 'failed',
-                            'errmsg': error_value.model.__name__ + ': 模型字段校验失败, ' +
-                                      str([{' -> '.join(str(e) for e in error['loc']): error['msg']}
-                                           for error in error_value.errors()])},
+                            'errmsg': str([{' -> '.join(str(e) for e in error['loc']): error['msg']}
+                                           for error in error_value.errors()]),
+                            'err_type': error_value.model.__name__ + ': 模型字段验证错误'},
                            ensure_ascii=False)
 
         send_response(self.session_handler.session,
