@@ -2,13 +2,13 @@
 # @Create   : 2021/5/17 9:46
 # @Author   : yh
 # @Remark   : session处理类
-import typing as t
 import json
-from urllib.parse import unquote
+import typing as t
+from urllib.parse import unquote_plus
 
 from .conf_base import ConfBase
-from .exception import CError, HTTPMethodError, DataError, AuthError
 from .def_http_code import HttpCode, HttpType
+from .exception import CError, HTTPMethodError, DataError, AuthError
 
 
 class Request(ConfBase):
@@ -21,6 +21,7 @@ class Request(ConfBase):
         self.session = session  # session会话
         self.status_code = HttpCode.st_200_ok  # 默认的响应码
         self.response_content_type = 'application/json; charset=utf-8'  # 默认的response类型
+        self.url_map = None  # 所有的url
 
         self._request_headers_cls = None
         self._response_headers_cls = None
@@ -215,7 +216,7 @@ class Request(ConfBase):
             return self._GET
 
     @property
-    def POST(self) -> dict:
+    def POST(self) -> t.Any:
         """
         获取post方法传递的参数
         """
@@ -233,14 +234,14 @@ class Request(ConfBase):
             try:
                 data = parse_dict.get(
                     self.content_type.split(';')[0] if self.content_type else 'application/x-www-form-urlencoded')(
-                    post_data)
+                    unquote_plus(post_data))
             except TypeError:
                 raise DataError('不支持的body参数类型: %s，目前支持的类型(%s)' % (self.content_type, ','.join(parse_dict.keys())))
             self._POST = data
             return self._POST
 
     @property
-    def PUT(self) -> dict:
+    def PUT(self) -> t.Any:
         """
         获取put方法传递参数
         """
@@ -264,7 +265,7 @@ class Request(ConfBase):
         """
         解析x-www-form-urlencoded
         """
-        return {unquote(post.split('=')[0]): unquote(post.split('=')[1]) if len(post.split('=')) == 2 else ''
+        return {post.split('=')[0]: post.split('=')[1] if len(post.split('=')) == 2 else ''
                 for post in post_data.split('&')}
 
     @staticmethod
@@ -325,6 +326,18 @@ class Request(ConfBase):
         except TypeError:
             raise CError('session.GetHttpResponseHead().SetAddHead()')
 
+    def upload(self, path: str, overwrite=True) -> str:
+        """
+        存储上传的文件
+        :param path: 上传路径 <！！！ 只需要写上传路径，不要写文件名，此方法会返回文件名 ！！！>
+        :param overwrite: 如果已有此文件是否覆盖
+        :return: 上传的文件名
+        """
+        flag, file_name = self.session.UploadFile(path, overwrite)
+        if flag:
+            return file_name
+        raise CError("读取上传文件错误")
+
 
 class Response:
     """
@@ -337,6 +350,9 @@ class Response:
     def __str__(self):
         return self.msg
 
+    def __call__(self, *args, **kwargs):
+        return self.msg
+
 
 class View(ConfBase):
     def __init__(self, request: "Request", *args, **kwargs):
